<?php
namespace T3SBS\T3sbootstrap\DataProcessing;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer;
use TYPO3\CMS\Frontend\ContentObject\DataProcessorInterface;

/**
 * This data processor can be used for processing data from pi_flexform
 */
class FlexformProcessor implements DataProcessorInterface
{
    /**
     * Process data of a record to resolve File objects to the view
     *
     * @param ContentObjectRenderer $cObj The data of the content element or page
     * @param array $contentObjectConfiguration The configuration of Content Object
     * @param array $processorConfiguration The configuration of this processor
     * @param array $processedData Key/value store of processed data (e.g. to be passed to a Fluid View)
     * @return array the processed data as key/value store
     */
    public function process(ContentObjectRenderer $cObj, array $contentObjectConfiguration, array $processorConfiguration,  array $processedData)
    {

		$flexconf = array();

		if ($processedData['data']['CType'] == 'gridelements_pi1') {
			if ( $processedData['data']['tx_gridelements_backend_layout'] != 'collapsible_accordion'
			  || $processedData['data']['tx_gridelements_backend_layout'] != 'background_wrapper' 
			  || $processedData['data']['tx_gridelements_backend_layout'] != 'collapsible_accordion') {
				
				$flexconf['frame'] = $processedData['data']['flexform_frame'];				
			}
			$flexconf['hiddenXs'] = $processedData['data']['flexform_hiddenXs'];
			$flexconf['hiddenSm'] = $processedData['data']['flexform_hiddenSm'];
			$flexconf['hiddenMd'] = $processedData['data']['flexform_hiddenMd'];
			$flexconf['hiddenLg'] = $processedData['data']['flexform_hiddenLg'];
			$flexconf['hiddenPrint'] = $processedData['data']['flexform_hiddenPrint'];  
			$flexconf['rulerAfter'] = $processedData['data']['flexform_rulerAfter'];
			$flexconf['rulerBefore'] = $processedData['data']['flexform_rulerBefore'];
			$flexconf['indent'] = $processedData['data']['flexform_indent'];  
			$flexconf['topMargin'] = $processedData['data']['flexform_topMargin'];
			$flexconf['bottomMargin'] = $processedData['data']['flexform_bottomMargin'];  

		} else {
			$this->readFlexformIntoConf($processedData['data']['pi_flexform'], $flexconf); 	
		}

		if ($processedData['data']['CType'] == 'table') {			
			$processedData['tableClass'] = $flexconf['table_class'];	
		}
		if ($processedData['data']['CType'] == 't3sbs_panel') {			
			$processedData['panelState'] = $flexconf['panel_state'] ?: 'default';	
		}

		$class = array();
		$class = $flexconf['frame'] ? ' '.$flexconf['frame']:'';
		$class .= $flexconf['hiddenXs'] ? ' hidden-xs':'';
		$class .= $flexconf['hiddenSm'] ? ' hidden-sm':'';
		$class .= $flexconf['hiddenMd'] ? ' hidden-md':'';
		$class .= $flexconf['hiddenLg'] ? ' hidden-lg':'';
		$class .= $flexconf['hiddenPrint'] ? ' hidden-print':'';
		
		$class .= $flexconf['rulerAfter'] ? ' rulerAfter':'';
		$class .= $flexconf['rulerBefore'] ? ' rulerBefore':'';
		$class .= $flexconf['indent'] ? ' indent':'';

		$processedData['class'] = $class;

		$style = array();
		$style = $flexconf['topMargin'] ? 'margin-top: '.$flexconf['topMargin'].'px;':'';
		$style .= $flexconf['bottomMargin'] ? ' margin-bottom: '.$flexconf['bottomMargin'].'px;':'';

		$processedData['style'] = $style;

        return $processedData;
    }


	/**
     * Converts a given config in Flexform to a conf-Array
     * @param    string         Flexform data
     * @param    array         Array to write the data into, by reference
     * @param    boolean        is set if called recursive. Don't call function with this parameter, it's used inside the function only
     * @access     public
     *
     */
    public function readFlexformIntoConf($flexData, &$conf, $recursive=FALSE) {
        if ($recursive === FALSE) {
            $flexData = \TYPO3\CMS\Core\Utility\GeneralUtility::xml2array($flexData, 'T3');
        }

        if (is_array($flexData)) {
            if (isset($flexData['data']['sDEF']['lDEF'])) {
                $flexData = $flexData['data']['sDEF']['lDEF'];
            }

            foreach ($flexData as $key => $value) {
                if (is_array($value['el']) && count($value['el']) > 0) {
                    foreach ($value['el'] as $ekey => $element) {
                        if (isset($element['vDEF'])) {
                            $conf[$ekey] =  $element['vDEF'];
                        } else {
                            if(is_array($element)) {
                                $this->readFlexformIntoConf($element, $conf[$key][key($element)][$ekey], TRUE);
                            } else {
                                $this->readFlexformIntoConf($element, $conf[$key][$ekey], TRUE);
                            }
                        }
                    }
                } else {
                    $this->readFlexformIntoConf($value['el'], $conf[$key], TRUE);
                }
                if ($value['vDEF']) {
                    $conf[$key] = $value['vDEF'];
                }
            }
        }
	} 


}
